<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password,
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}

$canvi_comment_count = get_comments_number();
?>

<div id="comments" class="comments-area <?php echo get_option( 'show_avatars' ) ? 'show-avatars' : ''; ?>">

	<?php
	if ( have_comments() ) :
		;
		?>
        <h2 class="comments-title">
			<?php if ( '1' === $canvi_comment_count ) : ?>
				<?php esc_html_e( '1 comment', 'canvi' ); ?>
			<?php else : ?>
				<?php
				printf(
				/* translators: %s: comment count number. */
					esc_html( _nx( '%s comment', '%s comments', $canvi_comment_count, 'Comments title', 'canvi' ) ),
					esc_html( number_format_i18n( $canvi_comment_count ) )
				);
				?>
			<?php endif; ?>
        </h2><!-- .comments-title -->

        <ol class="comment-list">
			<?php
			wp_list_comments(
				array(
					'avatar_size' => 60,
					'style'       => 'ol',
					'short_ping'  => TRUE,
				)
			);
			?>
        </ol><!-- .comment-list -->

		<?php
		the_comments_pagination(
			array(
				/* translators: There is a space after page. */

				'mid_size'  => 0,
				'prev_text' => is_rtl() ? canvi_get_icon_svg( 'ui', 'arrow_right', 18 ) : canvi_get_icon_svg( 'ui', 'arrow_left', 18 ),
				'next_text' => is_rtl() ? canvi_get_icon_svg( 'ui', 'arrow_left', 18 ) : canvi_get_icon_svg( 'ui', 'arrow_right', 18 ),
			)
		);
		?>

		<?php if ( ! comments_open() ) : ?>
        <p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'canvi' ); ?></p>
	<?php endif; ?>
	<?php endif; ?>

	<?php
	comment_form(
		array(
			'logged_in_as'       => NULL,
			'title_reply'        => esc_html__( 'Leave a comment', 'canvi' ),
			'title_reply_before' => '<h4 id="reply-title" class="comment-reply-title">',
			'title_reply_after'  => '</h4>',
		)
	);
	?>

</div><!-- #comments -->
