<?php

if ( ! defined( 'CANVI_THEME_DIR' ) ) {
	define( 'CANVI_THEME_DIR', trailingslashit( get_template_directory() ) );
}

if ( ! defined( 'CANVI_THEME_URI' ) ) {
	define( 'CANVI_THEME_URI', trailingslashit( esc_url( get_template_directory_uri() ) ) );
}

if ( ! defined( 'CANVI_THEME_SETTINGS' ) ) {
	define( 'CANVI_THEME_SETTINGS', 'canvi-settings' );
}

if ( ! defined( 'CANVI_THEME_LIB' ) ) {
	define( 'CANVI_THEME_LIB', CANVI_THEME_DIR . 'inc/rocksite-lib/' );
}

if ( ! defined( 'CANVI_THEME_CONFIG' ) ) {
	define( 'CANVI_THEME_CONFIG', CANVI_THEME_LIB . 'config/' );
}

if ( ! defined( 'CANVI_THEME_CLASSES' ) ) {
	define( 'CANVI_THEME_CLASSES', CANVI_THEME_LIB . 'classes/' );
}

if ( ! defined( 'CANVI_THEME_FUNCTIONS' ) ) {
	define( 'CANVI_THEME_FUNCTIONS', CANVI_THEME_LIB . 'functions/' );
}

if ( ! defined( 'CANVI_THEME_INTEGRATIONS' ) ) {
	define( 'CANVI_THEME_INTEGRATIONS', CANVI_THEME_LIB . 'integrations/' );
}

if ( ! defined( 'CANVI_THEME_VENDOR' ) ) {
	define( 'CANVI_THEME_VENDOR', CANVI_THEME_LIB . 'vendor/' );
}

if ( ! defined( 'CANVI_THEME_ASSETS' ) ) {
	define( 'CANVI_THEME_ASSETS', CANVI_THEME_URI . 'assets/' );
}

if ( ! defined( 'CANVI_THEME_ADMIN_ASSETS' ) ) {
	define( 'CANVI_THEME_ADMIN_ASSETS', CANVI_THEME_URI . 'admin/assets/' );
}

if ( ! defined( 'CANVI_THEME_EXTEND' ) ) {
	define( 'CANVI_THEME_EXTEND', CANVI_THEME_LIB . 'extend/' );
}


/**
 * Load library files
 */

require_once CANVI_THEME_LIB . 'loader.php';

Canvi::get_instance();


// This theme requires WordPress 5.3 or later.
if ( version_compare( $GLOBALS['wp_version'], '5.3', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
}

if ( ! function_exists( 'canvi_theme_setup' ) ) {
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 *
	 * @return void

	 *
	 */
	function canvi_theme_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Twenty Twenty-One, use a find and replace
		 * to change 'canvi' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'canvi', get_template_directory() . '/languages' );

		Canvi::setup();

		/*
		* Adds starter content to highlight the theme on fresh sites.
		* This is done conditionally to avoid loading the starter content on every
		* page load, as it is a one-off operation only needed once in the customizer.
		*/
		if ( is_customize_preview() ) {
			require get_template_directory() . '/starter/starter-content.php';
			add_theme_support( 'starter-content', canvi_get_starter_content() );
		}


	}
}
add_action( 'after_setup_theme', 'canvi_theme_setup' );


/**
 * Enqueue scripts and styles.
 *
 * @return void

 *
 */
function canvi_scripts() {


	// RTL styles.
	wp_style_add_data( 'canvi-style', 'rtl', 'replace' );


	// Threaded comment reply styles.
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}


}

add_action( 'wp_enqueue_scripts', 'canvi_scripts' );




/** Enqueue non-latin language styles
 *
 * @return void

 *
 */
function canvi_non_latin_languages() {
	$custom_css = canvi_get_non_latin_css( 'front-end' );

	if ( $custom_css ) {
		wp_add_inline_style( 'canvi-style', $custom_css );
	}
}

add_action( 'wp_enqueue_scripts', 'canvi_non_latin_languages' );

// SVG Icons class.
require get_template_directory() . '/inc/twentytwentyone/classes/class-canvi-svg-icons.php';


// Enhance the theme by hooking into WordPress.
require get_template_directory() . '/inc/twentytwentyone/template-functions.php';

// Menu functions and filters.
require get_template_directory() . '/inc/twentytwentyone/menu-functions.php';

// Custom template tags for the theme.
require get_template_directory() . '/inc/twentytwentyone/template-tags.php';

// Social icons menu walker class

require get_template_directory() . '/inc/class-social-media-walker.php';





