<?php
/**
 * Custom Social Media Nav Walker by Aurooba Ahmed
 * This uses Font Awesome and adds in the correct icon by detecting the URL of the menu item.
 * You can use this by doing a custom wp_nav_menu query:
 * wp_nav_menu(array('items_wrap'=> '%3$s', 'walker' => new Canvi_WO_Nav_Social_Walker(), 'container'=>false, 'menu_class' => '', 'theme_location'=>'social', 'fallback_cb'=>false ));
 *
 */

class Canvi_WO_Nav_Social_Walker extends Walker_Nav_Menu {
	function start_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat( "\t", $depth );
		$output .= "\n$indent\n";
	}

	function end_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat( "\t", $depth );
		$output .= "$indent\n";
	}

	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		$indent      = ( $depth ) ? str_repeat( "\t", $depth ) : '';
		$class_names = $value = '';
		$classes     = empty( $item->classes ) ? array() : (array) $item->classes;
		$classes[]   = 'menu-item-' . $item->ID;
		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );
		$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';
		$id          = apply_filters( 'nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args );
		$id          = $id ? ' id="' . esc_attr( $id ) . '"' : '';
		$output      .= $indent . '';
		$attributes  = ! empty( $item->attr_title ) ? ' title="' . esc_attr( $item->attr_title ) . '"' : '';
		$attributes  .= ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) . '"' : '';
		$attributes  .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) . '"' : '';
		$attributes  .= ! empty( $item->url ) ? ' href="' . esc_attr( $item->url ) . '"' : '';
		$item_output = $args->before;
		if ( strpos( $item->url, 'facebook' ) !== FALSE ) {
			$item_output .= '<a' . $attributes . ' class="canvi-a-button-icon -small -rounded -facebook">' . canvi_get_icon_svg( 'social', 'facebook', 18 );
			$item_output .= '</a>';
			$item_output .= $args->after;
		} elseif ( strpos( $item->url, 'twitter' ) !== FALSE ) {
			$item_output .= '<a' . $attributes . ' class="canvi-a-button-icon -small -rounded -twitter">' . canvi_get_icon_svg( 'social', 'twitter', 18 );
			$item_output .= '</i></a>';
			$item_output .= $args->after;
		} elseif ( strpos( $item->url, 'instagram' ) !== FALSE ) {
			$item_output .= '<a' . $attributes . ' class="canvi-a-button-icon -small -rounded -instagram">' . canvi_get_icon_svg( 'social', 'instagram', 18 );
			$item_output .= '</i></a>';
			$item_output .= $args->after;
		} elseif ( strpos( $item->url, 'youtube' ) !== FALSE ) {
			$item_output .= '<a' . $attributes . ' class="canvi-a-button-icon -small -rounded -youtube">' . canvi_get_icon_svg( 'social', 'youtube', 18 );
			$item_output .= '</i></a>';
			$item_output .= $args->after;
		} elseif ( strpos( $item->url, 'snapchat' ) !== FALSE ) {
			$item_output .= '<a' . $attributes . ' class="canvi-a-button-icon -small -rounded -snapchat">' . canvi_get_icon_svg( 'social', 'snapchat', 18 );
			$item_output .= '</i></a>';
			$item_output .= $args->after;
		} elseif ( strpos( $item->url, 'vimeo' ) !== FALSE ) {
			$item_output .= '<a' . $attributes . ' class="canvi-a-button-icon -small -rounded -vimeo">' . canvi_get_icon_svg( 'social', 'vimeo', 18 );
			$item_output .= '</i></a>';
			$item_output .= $args->after;
		} elseif ( strpos( $item->url, 'linkedin' ) !== FALSE ) {
			$item_output .= '<a' . $attributes . ' class="canvi-a-button-icon -small -rounded -linkedin">' . canvi_get_icon_svg( 'social', 'linkedin', 18 );
			$item_output .= '</i></a>';
			$item_output .= $args->after;
		} elseif ( strpos( $item->url, 'pinterest' ) !== FALSE ) {
			$item_output .= '<a' . $attributes . ' class="canvi-a-button-icon -small -rounded -pinterest">' . canvi_get_icon_svg( 'social', 'pinterest', 18 );
			$item_output .= '</i></a>';
			$item_output .= $args->after;
		}


		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}

	function end_el( &$output, $item, $depth = 0, $args = array() ) {
		$output .= "\n";
	}
}