<?php


if ( ! class_exists( 'Canvi_Setup' ) ) {

	/**
	 * Root Class for initialize
	 */
	class Canvi_Setup extends Canvi_Base {

		public $sidebars;


		public function __construct( $config, $settings ) {

			parent::__construct( $config, $settings );


			$this->hooks();

			$this->run_adds();


		}

		public function hooks() {

			$this->add_action( 'widgets_init', $this, 'register_widgets_action' );
			$this->add_action( 'init', $this, 'canvi_register_blocks_styles' );

			$this->add_filter( 'body_class', $this, 'body_class_modyficator', 2, 2 );
			$this->add_filter( 'image_size_names_choose', $this, 'add_custom_image_sizes', 2, 2 );


		}

		public function theme_setup() {


			load_theme_textdomain( 'canvi', CANVI_THEME_DIR . '/languages' );

			// Gutenberg wide images
			add_theme_support( 'align-wide' );

			// Add default posts and comments RSS
			add_theme_support( 'automatic-feed-links' );

			// Document title.
			add_theme_support( 'title-tag' );

			//Adding Custom Logo support

			// Add support for Block Styles.
			add_theme_support( 'wp-block-styles' );

			// TO DO: Add support for block templates

			// add_theme_support( 'block-templates' );

			add_theme_support( 'custom-logo', $this->config->get_logo_attributes() );

			// Support for Post Thumbnails
			add_theme_support( 'post-thumbnails' );

			// Add theme support for selective refresh for widgets.
			add_theme_support( 'customize-selective-refresh-widgets' );

			// Add support for editor styles.

			add_theme_support( 'editor-styles' );


			$editor_stylesheet_path = './assets/css/full/theme-editor.css';

			// Note, the is_IE global variable is defined by WordPress and is used
			// to detect if the current browser is internet explorer.
			global $is_IE;
			if ( $is_IE ) {
				$editor_stylesheet_path = './assets/css/ie-editor.css';
			}

			// Enqueue editor styles.

			add_editor_style( $editor_stylesheet_path );

			// register all thumbnails sizes

			$this->add_image_sizes();

			// register all blocks patterns

			$this->register_blocks_patterns();

			$GLOBALS['content_width'] = apply_filters( 'canvi_content_width', 1200 );

			// Register all nav menu locations

			register_nav_menus( $this->config->get_menus_locations() );

			// Add support for responsive embedded content.
			add_theme_support( 'responsive-embeds' );


			// Add support for custom line height controls.
			add_theme_support( 'custom-line-height' );

			// Add support for experimental link color control.
			add_theme_support( 'experimental-link-color' );

			// Add support for experimental cover block spacing.
			add_theme_support( 'custom-spacing' );


			// Custom background color

			add_theme_support( 'custom-background', array(
				'default-color' => 'FFFFFF'
			) );

			/**
			 * Add post-formats support.
			 */
			add_theme_support(
				'post-formats',
				array(
					'link',
					'aside',
					'gallery',
					'image',
					'quote',
					'status',
					'video',
					'audio',
					'chat',
				)
			);

			/*
			 * Switch default core markup for search form, comment form, and comments
			 * to output valid HTML5.
			 */
			add_theme_support(
				'html5',
				array(
					'comment-form',
					'comment-list',
					'gallery',
					'caption',
					'style',
					'script',
					'navigation-widgets',
				)
			);


			// Add custom editor font sizes.
			add_theme_support(
				'editor-font-sizes',
				array(
					array(
						'name'      => esc_html__( 'Extra small', 'canvi' ),
						'shortName' => esc_html_x( 'XS', 'Font size', 'canvi' ),
						'size'      => 12,
						'slug'      => 'extra-small',
					),
					array(
						'name'      => esc_html__( 'Small', 'canvi' ),
						'shortName' => esc_html_x( 'S', 'Font size', 'canvi' ),
						'size'      => 14,
						'slug'      => 'small',
					),
					array(
						'name'      => esc_html__( 'Normal', 'canvi' ),
						'shortName' => esc_html_x( 'M', 'Font size', 'canvi' ),
						'size'      => 18,
						'slug'      => 'normal',
					),
					array(
						'name'      => esc_html__( 'Large', 'canvi' ),
						'shortName' => esc_html_x( 'L', 'Font size', 'canvi' ),
						'size'      => 22,
						'slug'      => 'large',
					),
					array(
						'name'      => esc_html__( 'Extra large', 'canvi' ),
						'shortName' => esc_html_x( 'XL', 'Font size', 'canvi' ),
						'size'      => 40,
						'slug'      => 'extra-large',
					),
					array(
						'name'      => esc_html__( 'Huge', 'canvi' ),
						'shortName' => esc_html_x( 'XXL', 'Font size', 'canvi' ),
						'size'      => 60,
						'slug'      => 'huge',
					),
					array(
						'name'      => esc_html__( 'Gigantic', 'canvi' ),
						'shortName' => esc_html_x( 'XXXL', 'Font size', 'canvi' ),
						'size'      => 96,
						'slug'      => 'gigantic',
					),
				)
			);


			// Editor color palette.
			$black             = get_theme_mod( 'global--color-black', $this->config->get_project_variables( 'global--color-black' ) );
			$text              = get_theme_mod( 'global--color-text-base', $this->config->get_project_variables( 'global--color-text-base' ) );
			$text_lighten      = get_theme_mod( 'global--color-text-lighten', $this->config->get_project_variables( 'global--color-text-lighten' ) );
			$warning           = get_theme_mod( 'global--color-warning', $this->config->get_project_variables( 'global--color-warning' ) );
			$primary_base      = get_theme_mod( 'global--color-primary-base', $this->config->get_project_variables( 'global--color-primary-base' ) );
			$secondary_base    = get_theme_mod( 'global--color-secondary', $this->config->get_project_variables( 'global--color-secondary' ) );
			$third_base        = get_theme_mod( 'global--color-third-base', $this->config->get_project_variables( 'global--color-third-base' ) );
			$third_lighten     = get_theme_mod( 'global--color-third-lighten', $this->config->get_project_variables( 'global--color-third-lighten' ) );
			$primary_lighten   = get_theme_mod( 'global--color-primary-lighten', $this->config->get_project_variables( 'global--color-primary-lighten' ) );
			$secondary_lighten = get_theme_mod( 'global--color-secondary-lighten', $this->config->get_project_variables( 'global--color-secondary-lighten' ) );
			$surface           = get_theme_mod( 'global--color-surface', $this->config->get_project_variables( 'global--color-surface' ) );
			$invert            = get_theme_mod( 'global--color-invert', $this->config->get_project_variables( 'global--color-invert' ) );
			$success           = get_theme_mod( 'global--color-success', $this->config->get_project_variables( 'global--color-success' ) );
			$gray_base         = get_theme_mod( 'global--color-gray-base', $this->config->get_project_variables( 'global--color-gray-base' ) );
			$gray_lighten      = get_theme_mod( 'global--color-gray-lighten', $this->config->get_project_variables( 'global--color-gray-lighten' ) );
			$gray_darken       = get_theme_mod( 'global--color-gray-darken', $this->config->get_project_variables( 'global--color-gray-darken' ) );


			add_theme_support(
				'editor-color-palette',
				array(
					array(
						'name'  => esc_html__( 'Black', 'canvi' ),
						'slug'  => 'black',
						'color' => $black,
					),
					array(
						'name'  => esc_html__( 'Text', 'canvi' ),
						'slug'  => 'text',
						'color' => $text,
					),

					array(
						'name'  => esc_html__( 'Text Lighten', 'canvi' ),
						'slug'  => 'text-lighten',
						'color' => $text_lighten,
					),
					array(
						'name'  => esc_html__( 'Primary Base', 'canvi' ),
						'slug'  => 'primary-base',
						'color' => $primary_base,
					),
					array(
						'name'  => esc_html__( 'Primary Lighten', 'canvi' ),
						'slug'  => 'primary-lighten',
						'color' => $primary_lighten,
					),
					array(
						'name'  => esc_html__( 'Secondary Base', 'canvi' ),
						'slug'  => 'secondary-base',
						'color' => $secondary_base,
					),
					array(
						'name'  => esc_html__( 'Secondary Lighten', 'canvi' ),
						'slug'  => 'secondary-lighten',
						'color' => $secondary_lighten,
					),
					array(
						'name'  => esc_html__( 'Third Base', 'canvi' ),
						'slug'  => 'third-base',
						'color' => $third_base,
					),
					array(
						'name'  => esc_html__( 'Third Lighten', 'canvi' ),
						'slug'  => 'third-lighten',
						'color' => $third_lighten,
					),
					array(
						'name'  => esc_html__( 'Surface', 'canvi' ),
						'slug'  => 'surface',
						'color' => $surface,
					),
					array(
						'name'  => esc_html__( 'Invert', 'canvi' ),
						'slug'  => 'invert',
						'color' => $invert,
					),
					array(
						'name'  => esc_html__( 'Warning', 'canvi' ),
						'slug'  => 'warning',
						'color' => $warning,
					),

					array(
						'name'  => esc_html__( 'Success', 'canvi' ),
						'slug'  => 'success',
						'color' => $success,
					),

					array(
						'name'  => esc_html__( 'Gray Base', 'canvi' ),
						'slug'  => 'gray-base',
						'color' => $gray_base,
					),

					array(
						'name'  => esc_html__( 'Gray Lighten', 'canvi' ),
						'slug'  => 'gray-lighten',
						'color' => $gray_lighten,
					),

					array(
						'name'  => esc_html__( 'Gray Darken', 'canvi' ),
						'slug'  => 'gray-darken',
						'color' => $gray_darken,
					),
				)
			);

			add_theme_support(
				'editor-gradient-presets',
				array(
					array(
						'name'     => esc_html__( 'Black to Invert', 'canvi' ),
						'gradient' => 'linear-gradient(160deg, ' . $black . ' 0%, ' . $invert . ' 100%)',
						'slug'     => 'black-to-invert',
					),
					array(
						'name'     => esc_html__( 'Invert to black', 'canvi' ),
						'gradient' => 'linear-gradient(160deg, ' . $invert . ' 0%, ' . $black . ' 100%)',
						'slug'     => 'invert-to-black',
					),
					array(
						'name'     => esc_html__( 'Primary to secondary', 'canvi' ),
						'gradient' => 'linear-gradient(160deg, ' . $primary_base . ' 0%, ' . $secondary_base . ' 100%)',
						'slug'     => 'primary-base-to-secondary-base',
					),
					array(
						'name'     => esc_html__( 'Secondary to primary', 'canvi' ),
						'gradient' => 'linear-gradient(160deg, ' . $secondary_base . ' 0%, ' . $primary_base . ' 100%)',
						'slug'     => 'secondary-base-to-primary-base',
					),
					array(
						'name'     => esc_html__( 'Secondary to third', 'canvi' ),
						'gradient' => 'linear-gradient(160deg, ' . $secondary_base . ' 0%, ' . $third_base . ' 100%)',
						'slug'     => 'secondary-base-to-third-base',
					),
					array(
						'name'     => esc_html__( 'Third to Secondary', 'canvi' ),
						'gradient' => 'linear-gradient(160deg, ' . $third_base . ' 0%, ' . $secondary_base . ' 100%)',
						'slug'     => 'third-base-to-secondary-base',
					),
					array(
						'name'     => esc_html__( 'Invert to surface', 'canvi' ),
						'gradient' => 'linear-gradient(160deg, ' . $invert . ' 0%, ' . $surface . ' 100%)',
						'slug'     => 'invert-to-surface',
					),
					array(
						'name'     => esc_html__( 'SUrface to Invert', 'canvi' ),
						'gradient' => 'linear-gradient(160deg, ' . $surface . ' 0%, ' . $invert . ' 100%)',
						'slug'     => 'surface-to-invert',
					),
				)
			);



		}

		/**
		 * Ads images sizes based on default settings
		 */

		public function add_image_sizes() {

			$sizes = $this->config->get_image_sizes();

			foreach ( $sizes as $size => $attributes ) {

				add_image_size( $size, $attributes[0], $attributes[1], $attributes[2] );

			}

		}

		/**
		 * Add Images Sizes to display in the editor
		 *
		 * @param $sizes
		 *
		 * @return array
		 */

		public function add_custom_image_sizes( $sizes ) {

			return array_merge( $sizes, $this->config->get_image_sizes_to_display() );

		}


		/**
		 * Register sidebars from the config
		 */

		public function register_widgets_action() {

			$this->sidebars = $this->config->get_sidebars();

			if ( is_array( $this->sidebars ) ) {

				foreach ( $this->sidebars as $sidebar ) {

					register_sidebar( $sidebar );

				}

			}

		}

		public function body_class_modyficator( $classes, $type = 'default' ) {

			global $post;

			$meta_option = '';


			/*check local page settings*/

			if ( isset( $post->ID ) ) {


				$page_template = get_post_meta( $post->ID, '_wp_page_template', TRUE );


				if ( $page_template == 'templates/portfolio-list.php' ) {
					$classes[] = 'page-portfolio-isotope';
				}

			}


			return $classes;
		}

		/**
		 * Register all blocks from the configuration
		 */


		public function register_blocks_patterns() {

			$categories = apply_filters( 'canvi_block_categories', $this->config->get_block_patterns_categories() );

			$blocks_patterns = apply_filters( 'canvi_block_patterns', $this->config->get_block_patterns( $categories ) );

			if ( function_exists( 'register_block_pattern_category' ) ) {

				foreach ( $categories as $name => $data ) {

					register_block_pattern_category( $name, $data );

				}


			}

			if ( function_exists( 'register_block_pattern' ) ) {

				foreach ( $blocks_patterns as $pattern_array ) {


					foreach ( $pattern_array as $name => $data ) {

						register_block_pattern( $name, $data );

					}


				}

			}

		}

		/**
		 * Register block styles from config file
		 */

		public function canvi_register_blocks_styles() {

			$styles = apply_filters( 'canvi_block_styles', $this->config->get_block_styles() );


			if ( function_exists( 'register_block_style' ) ) {

				foreach ( $styles as $block => $attributes ) {

					foreach ( $attributes as $single_attributes ) {

						register_block_style( $block, $single_attributes );
					}


				}


			}


		}


	}

}