<?php


if ( ! class_exists( 'Canvi_Component_Layout' ) ) {

	/**
	 * Class generates layout components
	 */
	class Canvi_Component_Layout {

		protected static $instance;


		private function __construct() {

		}

		/**
		 * Displays Logo Component
		 *
		 * @param $path
		 */

		public static function brand_logo() {

			?>
            <div class="site-logo canvi-s-main-header__logo"><?php the_custom_logo(); ?></div>
			<?php
		}

		/**
		 * Displays website description
		 *
		 * @param $description
		 */

		public static function site_description( $description ) {
			?>
            <p class="canvi-s-main-header__description">
				<?php echo $description; // phpcs:ignore WordPress.Security.EscapeOutput ?>
            </p>

			<?php
		}


		/**
		 * DIsplays website description
		 *
		 * @param $description
		 */

		public static function site_blog_info( $blog_info, $header_class ) {

			if ( is_front_page() && ! is_paged() ) { ?>
                <h1 class="<?php echo esc_attr( $header_class ); ?>"><?php echo esc_html( $blog_info ); ?></h1>
			<?php } elseif ( is_front_page() || is_home() ) { ?>
                <h1 class="<?php echo esc_attr( $header_class ); ?>"><a
                            href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php echo esc_html( $blog_info ); ?></a>
                </h1>
			<?php } else { ?>
                <p class="<?php echo esc_attr( $header_class ); ?>"><a
                            href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php echo esc_html( $blog_info ); ?></a>
                </p>
				<?php
			}


		}

		/**
		 * Generate site brand header
		 */

		public static function site_title_logo() {

			?>

            <div class="canvi-m-site-description" itemprop="headline">
                <h4 class="canvi-m-site-description__title"><a
                            href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php echo get_bloginfo( 'name', 'display' ); ?></a>
                </h4>
                <p class="canvi-m-site-description__description"><a
                            href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php echo get_bloginfo( 'description', 'display' ); ?></a>
                </p>
            </div>
			<?php


		}

		public static function content_featured_image( $size ) {

			global $post;
			?>
            <div class="canvi-o-content__featured-image">
				<?php the_post_thumbnail( 'full' ) ?>
            </div>
			<?php

		}

		public static function content_page_title() {

			global $post;

			?>

            <h2 class="canvi-o-content__title"><?php the_title() ?></h2>

			<?php

		}

		/**
		 * Displays article meta
		 *
		 * @param string $content
		 */

		public static function article_meta( $content = '' ) {
			?>
            <div class="canvi-o-content__meta"><?php echo $content; ?></div>
			<?php
		}


	}


}