<?php
/**
 * Custom template tags for this theme
 *
 */

if ( ! function_exists( 'canvi_posted_on' ) ) {
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 *
	 * @return void
	 *
	 */
	function canvi_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() )
		);
		echo '<span class="posted-on">';
		printf(
		/* translators: %s: publish date. */
			esc_html__( 'Published: %s', 'canvi' ),
			$time_string // phpcs:ignore WordPress.Security.EscapeOutput
		);
		echo '</span>';
	}
}

if ( ! function_exists( 'canvi_posted_by' ) ) {
	/**
	 * Prints HTML with meta information about theme author.
	 *
	 * @return void
	 *
	 */
	function canvi_posted_by() {
		if (  post_type_supports( get_post_type(), 'author' ) ) {
			echo '<span class="byline">';
			printf(
			/* translators: %s author name. */
				esc_html__( 'By %s', 'canvi' ),
				'<a href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" rel="author">' . esc_html( get_the_author() ) . '</a>'
			);
			echo '</span>';
		}
	}
}

if ( ! function_exists( 'canvi_single_meta_footer' ) ) {

	function canvi_single_meta_footer() {
		if ( has_tag() ) {

			echo '<div class="canvi-l-article__footer__left post-taxonomies">';
			/* translators: used between list items, there is a space after the comma. */
			$tags_list = get_the_tag_list( '',  ' ' );
			if ( $tags_list ) {
				printf(
				/* translators: %s: list of tags. */
					'<div class="tags-links">' . esc_html( '%s' ) . '</div>',
					$tags_list // phpcs:ignore WordPress.Security.EscapeOutput
				);
			}
			echo '</div>';

		}
		echo '<div class="canvi-l-article__footer__right">';

		do_action( 'canvi_action_share_buttons_after' );

		echo '</div>';
	}
}

if ( ! function_exists( 'canvi_single_meta_categories' ) ) {

	function canvi_single_meta_categories() {
		if ( has_category() || has_tag() ) {

			echo '<div class="canvi-c-chips-list">';

			/* translators: used between list items, there is a space after the comma. */
			$categories_list = get_the_category_list( ' ' );
			if ( $categories_list ) {
				echo $categories_list; // phpcs:ignore WordPress.Security.EscapeOutput
			}

			echo '</div>';

		}
	}
}


if ( ! function_exists( 'canvi_entry_meta_footer' ) ) {
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 * Footer entry meta is displayed differently in archives and single posts.
	 *
	 * @return void
	 *
	 */
	function canvi_entry_meta_footer() {

		// Early exit if not a post.
		if ( 'post' !== get_post_type() ) {
			return;
		}

		// Hide meta information on pages.
		if ( ! is_single() ) {

			if ( is_sticky() ) {
				echo '<p>' . esc_html_x( 'Featured post', 'Label for sticky posts', 'canvi' ) . '</p>';
			}

			$post_format = get_post_format();
			if ( 'aside' === $post_format || 'status' === $post_format ) {
				echo '<p><a href="' . esc_url( get_permalink() ) . '">' . canvi_continue_reading_text() . '</a></p>'; // phpcs:ignore WordPress.Security.EscapeOutput
			}

			// Posted on.
			canvi_posted_on();

			// Edit post link.
			edit_post_link(
				sprintf(
				/* translators: %s: Name of current post. Only visible to screen readers. */
					esc_html__( 'Edit %s', 'canvi' ),
					'<span class="screen-reader-text">' . get_the_title() . '</span>'
				),
				'<span class="edit-link">',
				'</span><br>'
			);

			if ( has_category() || has_tag() ) {

				echo '<div class="post-taxonomies">';

				/* translators: used between list items, there is a space after the comma. */
				$categories_list = get_the_category_list( __( ', ', 'canvi' ) );
				if ( $categories_list ) {
					printf(
					/* translators: %s: list of categories. */
						'<span class="cat-links">' . esc_html__( 'Categorized as %s', 'canvi' ) . ' </span>',
						$categories_list // phpcs:ignore WordPress.Security.EscapeOutput
					);
				}

				/* translators: used between list items, there is a space after the comma. */
				$tags_list = get_the_tag_list( '',  ' ' );
				if ( $tags_list ) {
					printf(
					/* translators: %s: list of tags. */
						'<span class="tags-links">' . esc_html__( 'Tagged %s', 'canvi' ) . '</span>',
						$tags_list // phpcs:ignore WordPress.Security.EscapeOutput
					);
				}
				echo '</div>';
			}
		} else {

			echo '<div class="posted-by">';
			// Posted on.
			canvi_posted_on();
			// Posted by.
			canvi_posted_by();
			// Edit post link.
			edit_post_link(
				sprintf(
				/* translators: %s: Name of current post. Only visible to screen readers. */
					esc_html__( 'Edit %s', 'canvi' ),
					'<span class="screen-reader-text">' . get_the_title() . '</span>'
				),
				'<span class="edit-link">',
				'</span>'
			);
			echo '</div>';

			if ( has_category() || has_tag() ) {

				echo '<div class="post-taxonomies">';

				/* translators: used between list items, there is a space after the comma. */
				$categories_list = get_the_category_list( __( ', ', 'canvi' ) );
				if ( $categories_list ) {
					printf(
					/* translators: %s: list of categories. */
						'<span class="cat-links">' . esc_html__( 'Categorized as %s', 'canvi' ) . ' </span>',
						$categories_list // phpcs:ignore WordPress.Security.EscapeOutput
					);
				}

				/* translators: used between list items, there is a space after the comma. */
				$tags_list = get_the_tag_list( '', __( ', ', 'canvi' ) );
				if ( $tags_list ) {
					printf(
					/* translators: %s: list of tags. */
						'<span class="tags-links">' . esc_html__( 'Tagged %s', 'canvi' ) . '</span>',
						$tags_list // phpcs:ignore WordPress.Security.EscapeOutput
					);
				}
				echo '</div>';
			}
		}
	}
}

if ( ! function_exists( 'canvi_post_thumbnail' ) ) {
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 *
	 * @return void
	 *
	 */
	function canvi_post_thumbnail() {
		if ( ! canvi_can_show_post_thumbnail() ) {
			return;
		}
		?>

		<?php if ( is_singular() ) : ?>

            <figure class="canvi-l-article__header__thumbnail post-thumbnail">
				<?php
				// Thumbnail is loaded eagerly because it's going to be in the viewport immediately.
				the_post_thumbnail( 'post-thumbnail', array( 'loading' => 'eager' ) );
				?>
				<?php if ( wp_get_attachment_caption( get_post_thumbnail_id() ) ) : ?>
                    <figcaption
                            class="wp-caption-text"><?php echo wp_kses_post( wp_get_attachment_caption( get_post_thumbnail_id() ) ); ?></figcaption>
				<?php endif; ?>
            </figure><!-- .post-thumbnail -->

		<?php else : ?>

            <figure class="post-thumbnail">
                <a class="post-thumbnail-inner alignwide" href="<?php the_permalink(); ?>" aria-hidden="true"
                   tabindex="-1">
					<?php the_post_thumbnail( 'post-thumbnail' ); ?>
                </a>
				<?php if ( wp_get_attachment_caption( get_post_thumbnail_id() ) ) : ?>
                    <figcaption
                            class="wp-caption-text"><?php echo wp_kses_post( wp_get_attachment_caption( get_post_thumbnail_id() ) ); ?></figcaption>
				<?php endif; ?>
            </figure>

		<?php endif; ?>
		<?php
	}
}

if ( ! function_exists( 'canvi_the_posts_navigation' ) ) {
	/**
	 * Print the next and previous posts navigation.
	 *
	 * @return void
	 *
	 */
	function canvi_the_posts_navigation() {
		$post_type      = get_post_type_object( get_post_type() );
		$post_type_name = '';
		if (
			is_object( $post_type ) &&
			property_exists( $post_type, 'labels' ) &&
			is_object( $post_type->labels ) &&
			property_exists( $post_type->labels, 'name' )
		) {
			$post_type_name = $post_type->labels->name;
		}

		the_posts_pagination(
			array(
				/* translators: There is a space after page. */

				'mid_size'  => 0,
				'prev_text' => is_rtl() ? canvi_get_icon_svg( 'ui', 'arrow_right', 18 ) : canvi_get_icon_svg( 'ui', 'arrow_left', 18 ),
				'next_text' => is_rtl() ? canvi_get_icon_svg( 'ui', 'arrow_left', 18 ) : canvi_get_icon_svg( 'ui', 'arrow_right', 18 ),
			)
		);
	}
}

if ( ! function_exists( 'canvi_breadcrumbs' ) ) {

	function canvi_breadcrumbs() {

		$type = Canvi_Helper::get_content_type();

		$home      = esc_attr( Canvi_Settings::get( 'breadcrumbs_homepage_name', __( 'Home', 'canvi' ) ) );
		$separator = esc_attr( Canvi_Settings::get( 'breadcrumbs_separator', ' / ' ) );
		$display   = esc_attr( Canvi_Settings::get( $type . 'breadcrumbs_show', TRUE ) );

		global $post;


		//Get bredcrumb separator option
		$sep = '<span class="canvi-c-breadcrumbs__item__separator" >' . $separator . '</span>';

		$display = (bool) $display;

		if ( ! is_front_page() && $display === TRUE ) {
			echo '<div class="canvi-c-breadcrumbs">';
			echo '<ol class="canvi-c-breadcrumbs__links ">';
			echo '<li class="canvi-c-breadcrumbs__links__item"><a href="';
			echo esc_url( home_url() );
			echo '" >';
			echo $home;
			echo '</a>' . $sep . '</li>';

			if ( is_category() || is_single() ) {
				$args       = array( 'fields' => 'all' );
				$categories = wp_get_post_categories( $post->ID, $args );

				if ( count( $categories ) ) {

					if ( isset( $categories[0] ) ) {
						?>
                        <li class="canvi-c-breadcrumbs__links__item"><a
                                    href="<?php echo esc_url( get_category_link( $categories[0]->term_id ) ) ?>"><?php echo $categories[0]->name ?></a>
                        </li>
						<?php
					}

				}


			} elseif ( is_archive() || is_single() ) {

				?>
                <li class="canvi-c-breadcrumbs__item"><?php
					if ( is_day() ) {
						printf( '%s', get_the_date() );
					} elseif ( is_month() ) {
						printf( '%s', get_the_date( _x( 'F Y', 'monthly archives date format', 'canvi' ) ) );
					} elseif ( is_year() ) {
						printf( '%s', get_the_date( _x( 'Y', 'yearly archives date format', 'canvi' ) ) );
					} else {
						_e( 'Blog Archives', 'canvi' );
					}

					?></li>
				<?php

			}


			echo '</ol>';
			echo '</div>';
		}


	}
}

if ( ! function_exists( 'canvi_copyright' ) ) {

	function canvi_copyright( $class = '' ) {
		$copyright = esc_attr( Canvi_Settings::get( 'footer_copyright_text', __( 'Canvi Copyright', 'canvi' ) ) );

		if ( strlen( $copyright ) > 0 ) {

			?>
            <div class="powered-by<?php echo $class ?>">
				<?php echo $copyright; ?>
            </div>
			<?php

		}
	}

}

if ( ! function_exists( 'canvi_footer_description' ) ) {

	function canvi_footer_description() {
		$description = esc_attr( Canvi_Settings::get( 'footer_description_text', __( 'Footer Description', 'canvi' ) ) );

		if ( strlen( $description ) > 0 ) {

			?>
            <p class="footer-description">
				<?php echo $description; ?>
            </p>
			<?php

		}
	}

}


