<?php
/**
 * The searchform.php template.
 *
 * Used any time that get_search_form() is called.
 *
 * @link https://developer.wordpress.org/reference/functions/wp_unique_id/
 * @link https://developer.wordpress.org/reference/functions/get_search_form/
 *
 */

/*
 * Generate a unique ID for each form and a string containing an aria-label
 * if one was passed to get_search_form() in the args array.
 */
$canvi_unique_id = wp_unique_id( 'search-form-' );

$canvi_aria_label = ! empty( $args['aria_label'] ) ? 'aria-label="' . esc_attr( $args['aria_label'] ) . '"' : '';
?>
<form role="search" <?php echo $canvi_aria_label; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped above. ?>
      method="get" class="search-form" action="<?php echo esc_url( home_url( '/' ) ); ?>">
    <div class="canvi-c-search-field">
        <input type="search" placeholder="<?php _e( 'Search for ...', 'canvi' ); ?>"
               id="<?php echo esc_attr( $canvi_unique_id ); ?>" class="canvi-c-search-field__input"
               value="<?php echo get_search_query(); ?>" name="s"/>

        <button type="submit"
                class="canvi-c-search-field__button"><?php echo canvi_get_icon_svg( 'ui', 'search', 24 ); // phpcs:ignore WordPress.Security.EscapeOutput ?></button>
    </div>
</form>
